convert_semicolons_impl: Insert semicolons at the end of C++ statements

View source: R/RcppExports.R

convert_semicolons_implR Documentation

Insert semicolons at the end of C++ statements

Description

Appends a semicolon to each element of code that looks like a statement but does not already have one. Lines that are left unchanged: blank lines, lines already ending with ;, lines ending with { or }, C/C++ comments (// or /*), preprocessor directives (#), lines containing block options (line starts with @), and lines ending with Fortran block-structure keywords.

Usage

convert_semicolons_impl(code)

Arguments

code

Character vector of source lines.

Value

Character vector with semicolons inserted where needed.


mrgsolve documentation built on May 20, 2026, 9:06 a.m.