drop_re: Deprecated: drop random effect matrices from model object
Description
Deprecated: drop random effect matrices from model object
Usage
drop_re(.x, ...)drop.re(...)
Details
Users are no longer allowed to remove random effect matrices from the model
object. Use zero_re instead to convert the matrix to all zeros.