| env_get | R Documentation |
Call env_get() passing either a model object or simulated output and
name an object to retrieve from the model object environment.
env_get_obj() is an alias to env_get(). Call env_get_env() to
return the environment itself. Methods for mrgmod and mrgsims both
interact with the same environment (see Examples).
env_get(x, ...)
## S3 method for class 'mrgmod'
env_get(x, what, ...)
## S3 method for class 'mrgsims'
env_get(x, ...)
env_get_obj(x, ...)
env_get_env(x, ...)
## S3 method for class 'mrgmod'
env_get_env(x, ...)
## S3 method for class 'mrgsims'
env_get_env(x, ...)
x |
a model object (class |
... |
passed |
what |
the name of an object to return. |
mod <- house(end = 1)
# Just for the example
assign("let", letters[1:3], env_get_env(mod))
out <- mrgsim(mod)
env_get(out, "let")
env_get(mod, "let")
env_get_obj(out, "let")
env_get_env(mod)
# It's the same environment in out that is in mod
env_get_env(out)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.