Do an mrgsim run
do_mrgsim(x, data, idata = null_idata, carry.out = character(0),
seed = as.integer(NA), Request = character(0), capture = NULL,
obsonly = FALSE, obsaug = FALSE, tgrid = NULL, recsort = 1,
deslist = list(), descol = character(0), filbak = TRUE, tad = FALSE,
nocb = TRUE, skip_init_calc = FALSE, ...)a model object
a simulation data set
individual-level data
data items to copy into the output
deprecated
compartments or captured variables to retain in the simulated output
character file name used for debugging (not related
to $CAPTURE
if TRUE, dosing records are not included
in the output
augment the data set with time grid observations
a tgrid object; or a numeric vector of simulation times
or another object with an stime method
record sorting flag
a list of tgrid objects
the name of a column for assigning designs
carry data items backward when the first data set row has time greater than zero
if TRUE, include time after dose
in the output
if TRUE, use next observation carry
backward method; otherwise, use locf
don't use $MAIN to
calculate initial conditions
not used