| modelsplit | R Documentation |
modelsplit() parses model specification text into a named list of code
blocks, retaining enough information to reconstruct the original text.
modelunsplit() takes the list returned by modelsplit() and puts the
blocks back together into a character vector of model code.
modelsplit(x)
modelunsplit(x)
x |
for |
modelsplit() returns a named list of character vectors, one element
per block. modelunsplit() returns a character vector of model code.
modelparse() that drops blank lines and comments by default.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.