| modlib_pkpd | R Documentation |
modlib: Pharmacokinetic / pharmacodynamic models
See modlib_details for more detailed descriptions of parameters and compartments.
All PK/PD models include 2-compartment PK model with absorption from
2 extravascular compartments and linear + nonlinear clearance. The
PK models are parameterized with CL, V2, Q, V3, VMAX, KM, KAandKA2and implement compartmentsEV, EV2, CENT, PERIPH. The indirect response models have compartment RESPand the emax model has output variableRESP. PD parameters include KIN, KOUT, IC50, EC50, IMAX, EMAX, E0, and n'.
Also, once the model is loaded, use the see() method for mrgmod to
view the model code.
irm1: inhibition of response production
irm2: inhibition of response loss
irm3: stimulation of response production
irm4: stimulation of response loss
pd_effect: effect compartment model
emax: sigmoid emax model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.