Learn R Programming

mrgsolve (version 0.8.12)

read_nmext: Extract estimates from NONMEM ext file

Description

Extract estimates from NONMEM ext file

Usage

read_nmext(run, file = paste0(run, ".ext"), project = getwd())

Arguments

run

a run number or run identifier

file

the ext file name

project

the NONMEM project directory

Value

A list with theta, omega, and sigma in a format ready to be used to update a model object.

Examples

Run this code
# NOT RUN {
project <- system.file("nonmem", package = "mrgsolve")

est <- read_nmext(1005, project = project)

est$theta

est$omega

est$sigma

# }

Run the code above in your browser using DataLab