powered by
Extract estimates from NONMEM ext file
read_nmext(run, file = paste0(run, ".ext"), project = getwd())
a run number or run identifier
the ext file name
the NONMEM project directory
A list with theta, omega, and sigma in a format ready to be used to update a model object.
# NOT RUN { project <- system.file("nonmem", package = "mrgsolve") est <- read_nmext(1005, project = project) est$theta est$omega est$sigma # }
Run the code above in your browser using DataLab