Scrape options from a code block.
scrape_opts(x, envir = list(), def = list(), all = TRUE, marker = "=",
narrow = TRUE)data
environment from $ENV
default values
return all options, even those that are not in def
assignment operator; used to locate lines with options
logical; if TRUE, only get options on lines starting with >>
list with elements x (the data without options) and named options
as specified in the block.